@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 #--
 # Copyright 2006, 2007 by Chad Fowler, Rich Kilmer, Jim Weirich, Eric Hodel
 # and others.
@@ -5,6 +6,11 @@
 # See LICENSE.txt for permissions.
 #++
 
+if RUBY_VERSION < "1.8.7"
+  $stderr.puts "RubyGems now requires Ruby 1.8.7 or later"
+  exit 1
+end
+
 # Make sure rubygems isn't already loaded.
 if ENV['RUBYOPT'] or defined? Gem then
   ENV.delete 'RUBYOPT'
@@ -31,7 +37,9 @@ require 'rubygems/exceptions'
 Gem::CommandManager.instance.register_command :setup
 
 args = ARGV.clone
-
+if ENV["GEM_PREV_VER"]
+  args = [ '--previous-version', ENV["GEM_PREV_VER"] ] + args
+end
 args.unshift 'setup'
 
 begin
